/*	Author :	Chad P. Bown & Meredith A. Crowley							*/
/*	Date : 			27 October 2011						        			*/
/*	Revised :		8 August 2012							    			*/
/*	Desc : 		Bown-Crowley macro determinants, creates Table 2 estimates	*/
/*	Input :	data\quarterly_bilateral\quarterly_bi_INDUSTRIALIZED-5.dta		*/
/*	Output :																*/ 
/*																			*/
/*	Next :																	*/

clear
set mem 750m

version 7.0
#delimit ;
set more off;

cd MY_PATH;

log using data\quarterly_bilateral\Table-2-08-08-2012, replace;


/* TABLE 2 -- 1988:Q1-2008:Q3: Pre-crisis sample of data, baseline specification and robustness checks */
/* *********** */
/* 1. BASELINE */
/* *********** */
#delimit;
clear;
use data\quarterly_bilateral\quarterly_bi_INDUSTRIALIZED-5.dta;
keep if twithin(1987-4,2008-4);

xi: nbreg all_init_prod  pchg_rxr_yoy_lag1  chg_unemp_yoy_lag1 fgdp_gr_lag1	quarter
	i.cty_partner, nolog irr ;

	
/* ************************************************************************* */
/* ALGORITHM: PREDICT THE NUMBER OF INITIATIONS IN RESPONSE TO A ONE STANDARD DEVIATION CHANGE IN EACH VARIABLE OF INTEREST */
/* PRE CRISIS SAMPLE OF DATA: 1988:Q1-2008:Q3 */

keep if e(sample)==1;
summarize all_init_prod ad_init_prod pchg_rxr_yoy_lag1 chg_unemp_yoy_lag1 rgdp_gr_lag1 fgdp_gr_lag1;
	
predict count_median;

 egen sd_pchg_rxr_yoy_lag1=sd(pchg_rxr_yoy_lag1);
 egen sd_chg_unemp_yoy_lag1=sd(chg_unemp_yoy_lag1);
 egen sd_fgdp_gr_lag1=sd(fgdp_gr_lag1);
 

/*	MEAN + ONE STANDARD DEVIATION INCREASE IN RXR */

						/* save versions of the old data to change back for the other shocks */
					gen pchg_rxr_yoy_lag1_old=pchg_rxr_yoy_lag1;

/* ****** ADD A ONE STANDARD DEVIATION INCREASE TO EACH OBSERVATION ****** */

					replace pchg_rxr_yoy_lag1 = pchg_rxr_yoy_lag1_old+sd_pchg_rxr_yoy_lag1;
predict count_pchg_rxr_yoy_lag1_sd;



/*	MEAN + ONE STANDARD DEVIATION INCREASE IN DOMESTIC UNEMPLOYMENT RATE */

						/* save versions of the old data to change back for the other shocks */
					gen chg_unemp_yoy_lag1_old=chg_unemp_yoy_lag1;
					
						/* change back previously shocked data */
					replace pchg_rxr_yoy_lag1=pchg_rxr_yoy_lag1_old;

/* ****** ADD A ONE STANDARD DEVIATION INCREASE TO EACH OBSERVATION ****** */

					replace chg_unemp_yoy_lag1 = chg_unemp_yoy_lag1_old+sd_chg_unemp_yoy_lag1;
predict count_chg_unemp_yoy_lag1_sd;

					
/*	MEAN + ONE STANDARD DEVIATION DECREASE IN FOREIGN REAL GDP */

						/* save versions of the old data to change back for the other shocks */
					gen fgdp_gr_lag1_old=fgdp_gr_lag1;

						/* change back previously shocked data */
					replace chg_unemp_yoy_lag1=chg_unemp_yoy_lag1_old;

/* ****** SUBTRACT A ONE STANDARD DEVIATION CHANGE FROM EACH OBSERVATION ****** */

					replace fgdp_gr_lag1 = fgdp_gr_lag1_old-sd_fgdp_gr_lag1;
predict count_fgdp_gr_lag1_sd;

/* ****** DETERMINE THE MEDIAN NUMBER OF INITIATIONS FOR EACH EXPERIMENT ****** */

collapse (median) all_init_prod ad_init_prod count_median count_pchg_rxr_yoy_lag1_sd count_chg_unemp_yoy_lag1_sd count_fgdp_gr_lag1_sd ;


	/* *** PREDICTION:  *** */
list all_init_prod ad_init_prod count_median count_pchg_rxr_yoy_lag1_sd count_chg_unemp_yoy_lag1_sd count_fgdp_gr_lag1_sd ;
/* ************************************************************************* */
	
	/* *********** */
/* 2. BASELINE: USE DOMESTIC REAL GDP INSTEAD OF UNEMPLOYMENT CHANGE */
/* *********** */
#delimit;
clear;
use data\quarterly_bilateral\quarterly_bi_INDUSTRIALIZED-5.dta;
keep if twithin(1987-4,2008-4);

xi: nbreg all_init_prod  pchg_rxr_yoy_lag1 rgdp_gr_lag1 fgdp_gr_lag1 quarter
	i.cty_partner, nolog irr ;

/* ************************************************************************* */
/* ALGORITHM: PREDICT THE NUMBER OF INITIATIONS IN RESPONSE TO A ONE STANDARD DEVIATION CHANGE IN EACH VARIABLE OF INTEREST */
/* PRE CRISIS SAMPLE OF DATA: 1988:Q1-2008:Q3 */

keep if e(sample)==1;
summarize all_init_prod ad_init_prod pchg_rxr_yoy_lag1 chg_unemp_yoy_lag1 rgdp_gr_lag1 fgdp_gr_lag1;
	
predict count_median;

 egen sd_pchg_rxr_yoy_lag1=sd(pchg_rxr_yoy_lag1);
 egen sd_rgdp_gr_lag1=sd(rgdp_gr_lag1);
 egen sd_fgdp_gr_lag1=sd(fgdp_gr_lag1);
 
/*	MEAN + ONE STANDARD DEVIATION INCREASE IN RXR */

						/* save versions of the old data to change back for the other shocks */
					gen pchg_rxr_yoy_lag1_old=pchg_rxr_yoy_lag1;

/* ****** ADD A ONE STANDARD DEVIATION INCREASE TO EACH OBSERVATION ****** */

					replace pchg_rxr_yoy_lag1 = pchg_rxr_yoy_lag1_old+sd_pchg_rxr_yoy_lag1;
predict count_pchg_rxr_yoy_lag1_sd;



/*	MEAN + ONE STANDARD DEVIATION DECREASE IN DOMESTIC REAL GDP */

						/* save versions of the old data to change back for the other shocks */
					gen rgdp_gr_lag1_old=rgdp_gr_lag1;
					
						/* change back previously shocked data */
					replace pchg_rxr_yoy_lag1=pchg_rxr_yoy_lag1_old;

/* ****** SUBTRACT A ONE STANDARD DEVIATION CHANGE FROM EACH OBSERVATION ****** */

					replace rgdp_gr_lag1 = rgdp_gr_lag1_old-sd_rgdp_gr_lag1;
predict count_rgdp_gr_lag1_sd;

					
/*	MEAN + ONE STANDARD DEVIATION DECREASE IN FOREIGN REAL GDP */

						/* save versions of the old data to change back for the other shocks */
					gen fgdp_gr_lag1_old=fgdp_gr_lag1;

						/* change back previously shocked data */
					replace rgdp_gr_lag1=rgdp_gr_lag1_old;

/* ****** SUBTRACT A ONE STANDARD DEVIATION CHANGE FROM EACH OBSERVATION ****** */

					replace fgdp_gr_lag1 = fgdp_gr_lag1_old-sd_fgdp_gr_lag1;
predict count_fgdp_gr_lag1_sd;

/* ****** DETERMINE THE MEDIAN NUMBER OF INITIATIONS FOR EACH EXPERIMENT ****** */
collapse (median) all_init_prod ad_init_prod count_median count_pchg_rxr_yoy_lag1_sd count_rgdp_gr_lag1_sd count_fgdp_gr_lag1_sd ;


	/* *** PREDICTION:  *** */
list all_init_prod ad_init_prod count_median count_pchg_rxr_yoy_lag1_sd count_rgdp_gr_lag1_sd count_fgdp_gr_lag1_sd ;
/* ************************************************************************* */
	
/* *********** */	
/* 3. BASELINE, MODIFIED FIXED EFFECTS */
/* *********** */
#delimit;
clear;
use data\quarterly_bilateral\quarterly_bi_INDUSTRIALIZED-5.dta;
keep if twithin(1987-4,2008-4);

xi: nbreg all_init_prod  pchg_rxr_yoy_lag1  chg_unemp_yoy_lag1 fgdp_gr_lag1	quarter
	i.cty_code i.partner_num, nolog irr ;

	
/* ************************************************************************* */
/* ALGORITHM: PREDICT THE NUMBER OF INITIATIONS IN RESPONSE TO A ONE STANDARD DEVIATION CHANGE IN EACH VARIABLE OF INTEREST */
/* PRE CRISIS SAMPLE OF DATA: 1988:Q1-2008:Q3 */

keep if e(sample)==1;
summarize all_init_prod ad_init_prod pchg_rxr_yoy_lag1 chg_unemp_yoy_lag1 rgdp_gr_lag1 fgdp_gr_lag1;
	
predict count_median;

 egen sd_pchg_rxr_yoy_lag1=sd(pchg_rxr_yoy_lag1);
 egen sd_chg_unemp_yoy_lag1=sd(chg_unemp_yoy_lag1);
 egen sd_fgdp_gr_lag1=sd(fgdp_gr_lag1);
 
/*	MEAN + ONE STANDARD DEVIATION INCREASE IN RXR */

						/* save versions of the old data to change back for the other shocks */
					gen pchg_rxr_yoy_lag1_old=pchg_rxr_yoy_lag1;

/* ****** ADD A ONE STANDARD DEVIATION INCREASE TO EACH OBSERVATION ****** */

					replace pchg_rxr_yoy_lag1 = pchg_rxr_yoy_lag1_old+sd_pchg_rxr_yoy_lag1;
predict count_pchg_rxr_yoy_lag1_sd;



/*	MEAN + ONE STANDARD DEVIATION INCREASE IN DOMESTIC UNEMPLOYMENT RATE */

						/* save versions of the old data to change back for the other shocks */
					gen chg_unemp_yoy_lag1_old=chg_unemp_yoy_lag1;
					
						/* change back previously shocked data */
					replace pchg_rxr_yoy_lag1=pchg_rxr_yoy_lag1_old;

/* ****** ADD A ONE STANDARD DEVIATION INCREASE TO EACH OBSERVATION ****** */

					replace chg_unemp_yoy_lag1 = chg_unemp_yoy_lag1_old+sd_chg_unemp_yoy_lag1;
predict count_chg_unemp_yoy_lag1_sd;

					
/*	MEAN + ONE STANDARD DEVIATION DECREASE IN FOREIGN REAL GDP */

						/* save versions of the old data to change back for the other shocks */
					gen fgdp_gr_lag1_old=fgdp_gr_lag1;

						/* change back previously shocked data */
					replace chg_unemp_yoy_lag1=chg_unemp_yoy_lag1_old;

/* ****** SUBTRACT A ONE STANDARD DEVIATION CHANGE FROM EACH OBSERVATION ****** */

					replace fgdp_gr_lag1 = fgdp_gr_lag1_old-sd_fgdp_gr_lag1;
predict count_fgdp_gr_lag1_sd;

/* ****** DETERMINE THE MEDIAN NUMBER OF INITIATIONS FOR EACH EXPERIMENT ****** */
collapse (median) all_init_prod ad_init_prod count_median count_pchg_rxr_yoy_lag1_sd count_chg_unemp_yoy_lag1_sd count_fgdp_gr_lag1_sd ;


	/* *** PREDICTION:  *** */
list all_init_prod ad_init_prod count_median count_pchg_rxr_yoy_lag1_sd count_chg_unemp_yoy_lag1_sd count_fgdp_gr_lag1_sd ;
/* ************************************************************************* */


/* *********** */	
/* 4. BASELINE: USE 2nd LAG INSTEAD OF 1st */
/* *********** */
#delimit;
clear;
use data\quarterly_bilateral\quarterly_bi_INDUSTRIALIZED-5.dta;
keep if twithin(1987-4,2008-4);

xi: nbreg all_init_prod  pchg_rxr_yoy_lag2 chg_unemp_yoy_lag2 fgdp_gr_lag2 quarter
	i.cty_partner, nolog irr ;

/* ************************************************************************* */
/* ALGORITHM: PREDICT THE NUMBER OF INITIATIONS IN RESPONSE TO A ONE STANDARD DEVIATION CHANGE IN EACH VARIABLE OF INTEREST */
/* PRE CRISIS SAMPLE OF DATA: 1988:Q1-2008:Q3 */

keep if e(sample)==1;
summarize all_init_prod ad_init_prod pchg_rxr_yoy_lag2 chg_unemp_yoy_lag2 rgdp_gr_lag2 fgdp_gr_lag2;
	
predict count_median;

 egen sd_pchg_rxr_yoy_lag2=sd(pchg_rxr_yoy_lag2);
 egen sd_chg_unemp_yoy_lag2=sd(chg_unemp_yoy_lag2);
 egen sd_fgdp_gr_lag2=sd(fgdp_gr_lag2);
 
/*	MEAN + ONE STANDARD DEVIATION INCREASE IN RXR */

						/* save versions of the old data to change back for the other shocks */
					gen pchg_rxr_yoy_lag2_old=pchg_rxr_yoy_lag2;

/* ****** ADD A ONE STANDARD DEVIATION INCREASE TO EACH OBSERVATION ****** */

					replace pchg_rxr_yoy_lag2 = pchg_rxr_yoy_lag2_old+sd_pchg_rxr_yoy_lag2;
predict count_pchg_rxr_yoy_lag2_sd;



/*	MEAN + ONE STANDARD DEVIATION INCREASE IN DOMESTIC UNEMPLOYMENT RATE */

						/* save versions of the old data to change back for the other shocks */
					gen chg_unemp_yoy_lag2_old=chg_unemp_yoy_lag2;
					
						/* change back previously shocked data */
					replace pchg_rxr_yoy_lag2=pchg_rxr_yoy_lag2_old;

/* ****** ADD A ONE STANDARD DEVIATION INCREASE TO EACH OBSERVATION ****** */

					replace chg_unemp_yoy_lag2 = chg_unemp_yoy_lag2_old+sd_chg_unemp_yoy_lag2;
predict count_chg_unemp_yoy_lag2_sd;

					
/*	MEAN + ONE STANDARD DEVIATION DECREASE IN FOREIGN REAL GDP */

						/* save versions of the old data to change back for the other shocks */
					gen fgdp_gr_lag2_old=fgdp_gr_lag2;

						/* change back previously shocked data */
					replace chg_unemp_yoy_lag2=chg_unemp_yoy_lag2_old;

/* ****** SUBTRACT A ONE STANDARD DEVIATION CHANGE FROM EACH OBSERVATION ****** */

					replace fgdp_gr_lag2 = fgdp_gr_lag2_old-sd_fgdp_gr_lag2;
predict count_fgdp_gr_lag2_sd;

/* ****** DETERMINE THE MEDIAN NUMBER OF INITIATIONS FOR EACH EXPERIMENT ****** */
collapse (median) all_init_prod ad_init_prod count_median count_pchg_rxr_yoy_lag2_sd count_chg_unemp_yoy_lag2_sd count_fgdp_gr_lag2_sd ;


	/* *** PREDICTION:  *** */
list all_init_prod ad_init_prod count_median count_pchg_rxr_yoy_lag2_sd count_chg_unemp_yoy_lag2_sd count_fgdp_gr_lag2_sd ;
/* ************************************************************************* */

/* *********** */
/* 5. BASELINE: USE AD, NOT ALL TTBS */
/* *********** */
#delimit;
clear;
use data\quarterly_bilateral\quarterly_bi_INDUSTRIALIZED-5.dta;
keep if twithin(1987-4,2008-4);

xi: nbreg ad_init_prod  pchg_rxr_yoy_lag1  chg_unemp_yoy_lag1 fgdp_gr_lag1	quarter 
	i.cty_partner, nolog irr ;

/* ************************************************************************* */
/* ALGORITHM: PREDICT THE NUMBER OF INITIATIONS IN RESPONSE TO A ONE STANDARD DEVIATION CHANGE IN EACH VARIABLE OF INTEREST */
/* PRE CRISIS SAMPLE OF DATA: 1988:Q1-2008:Q3 */

keep if e(sample)==1;
summarize all_init_prod ad_init_prod pchg_rxr_yoy_lag1 chg_unemp_yoy_lag1 rgdp_gr_lag1 fgdp_gr_lag1;
	
predict count_median;

 egen sd_pchg_rxr_yoy_lag1=sd(pchg_rxr_yoy_lag1);
 egen sd_chg_unemp_yoy_lag1=sd(chg_unemp_yoy_lag1);
 egen sd_fgdp_gr_lag1=sd(fgdp_gr_lag1);
 
/*	MEAN + ONE STANDARD DEVIATION INCREASE IN RXR */

						/* save versions of the old data to change back for the other shocks */
					gen pchg_rxr_yoy_lag1_old=pchg_rxr_yoy_lag1;

/* ****** ADD A ONE STANDARD DEVIATION INCREASE TO EACH OBSERVATION ****** */

					replace pchg_rxr_yoy_lag1 = pchg_rxr_yoy_lag1_old+sd_pchg_rxr_yoy_lag1;
predict count_pchg_rxr_yoy_lag1_sd;



/*	MEAN + ONE STANDARD DEVIATION INCREASE IN DOMESTIC UNEMPLOYMENT RATE */

						/* save versions of the old data to change back for the other shocks */
					gen chg_unemp_yoy_lag1_old=chg_unemp_yoy_lag1;
					
						/* change back previously shocked data */
					replace pchg_rxr_yoy_lag1=pchg_rxr_yoy_lag1_old;

/* ****** ADD A ONE STANDARD DEVIATION INCREASE TO EACH OBSERVATION ****** */

					replace chg_unemp_yoy_lag1 = chg_unemp_yoy_lag1_old+sd_chg_unemp_yoy_lag1;
predict count_chg_unemp_yoy_lag1_sd;

					
/*	MEAN + ONE STANDARD DEVIATION DECREASE IN FOREIGN REAL GDP */

						/* save versions of the old data to change back for the other shocks */
					gen fgdp_gr_lag1_old=fgdp_gr_lag1;

						/* change back previously shocked data */
					replace chg_unemp_yoy_lag1=chg_unemp_yoy_lag1_old;

/* ****** SUBTRACT A ONE STANDARD DEVIATION CHANGE FROM EACH OBSERVATION ****** */

					replace fgdp_gr_lag1 = fgdp_gr_lag1_old-sd_fgdp_gr_lag1;
predict count_fgdp_gr_lag1_sd;

/* ****** DETERMINE THE MEDIAN NUMBER OF INITIATIONS FOR EACH EXPERIMENT ****** */
collapse (median) all_init_prod ad_init_prod count_median count_pchg_rxr_yoy_lag1_sd count_chg_unemp_yoy_lag1_sd count_fgdp_gr_lag1_sd ;


	/* *** PREDICTION:  *** */
list all_init_prod ad_init_prod count_median count_pchg_rxr_yoy_lag1_sd count_chg_unemp_yoy_lag1_sd count_fgdp_gr_lag1_sd ;
/* ************************************************************************* */

/* *********** */
/* 6. BASELINE, INCLUDE INTERACTION TERM OF DOMESTIC UNEMPLOYMENT CHANGE AND FOREIGN GDP GROWTH */
/* *********** */
#delimit;
clear;
use data\quarterly_bilateral\quarterly_bi_INDUSTRIALIZED-5.dta;
keep if twithin(1987-4,2008-4);

xi: nbreg all_init_prod  pchg_rxr_yoy_lag1  chg_unemp_yoy_lag1 fgdp_gr_lag1	quarter shared_unemp_lag1
	i.cty_partner, nolog irr ;

/* ************************************************************************* */
/* ALGORITHM: PREDICT THE NUMBER OF INITIATIONS IN RESPONSE TO A ONE STANDARD DEVIATION CHANGE IN EACH VARIABLE OF INTEREST */
/* PRE CRISIS SAMPLE OF DATA: 1988:Q1-2008:Q3 */

keep if e(sample)==1;
summarize all_init_prod ad_init_prod pchg_rxr_yoy_lag1 chg_unemp_yoy_lag1 rgdp_gr_lag1 fgdp_gr_lag1 shared_unemp_lag1;
	
predict count_median;

 egen sd_pchg_rxr_yoy_lag1=sd(pchg_rxr_yoy_lag1);
 egen sd_chg_unemp_yoy_lag1=sd(chg_unemp_yoy_lag1);
 egen sd_fgdp_gr_lag1=sd(fgdp_gr_lag1);
 egen sd_shared_unemp_lag1=sd(shared_unemp_lag1); 
 
/*	MEAN + ONE STANDARD DEVIATION INCREASE IN RXR */

						/* save versions of the old data to change back for the other shocks */
					gen pchg_rxr_yoy_lag1_old=pchg_rxr_yoy_lag1;

/* ****** ADD A ONE STANDARD DEVIATION INCREASE TO EACH OBSERVATION ****** */

					replace pchg_rxr_yoy_lag1 = pchg_rxr_yoy_lag1_old+sd_pchg_rxr_yoy_lag1;
predict count_pchg_rxr_yoy_lag1_sd;



/*	MEAN + ONE STANDARD DEVIATION INCREASE IN DOMESTIC UNEMPLOYMENT RATE */

						/* save versions of the old data to change back for the other shocks */
					gen chg_unemp_yoy_lag1_old=chg_unemp_yoy_lag1;
					
						/* change back previously shocked data */
					replace pchg_rxr_yoy_lag1=pchg_rxr_yoy_lag1_old;

/* ****** ADD A ONE STANDARD DEVIATION INCREASE TO EACH OBSERVATION ****** */

					replace chg_unemp_yoy_lag1 = chg_unemp_yoy_lag1_old+sd_chg_unemp_yoy_lag1;
predict count_chg_unemp_yoy_lag1_sd;

					
/*	MEAN + ONE STANDARD DEVIATION DECREASE IN FOREIGN REAL GDP */

						/* save versions of the old data to change back for the other shocks */
					gen fgdp_gr_lag1_old=fgdp_gr_lag1;

						/* change back previously shocked data */
					replace chg_unemp_yoy_lag1=chg_unemp_yoy_lag1_old;

/* ****** SUBTRACT A ONE STANDARD DEVIATION CHANGE FROM EACH OBSERVATION ****** */

					replace fgdp_gr_lag1 = fgdp_gr_lag1_old-sd_fgdp_gr_lag1;
predict count_fgdp_gr_lag1_sd;


/*	MEAN + ONE STANDARD DEVIATION INCREASE IN INTERACTION TERM */

						/* save versions of the old data to change back for the other shocks */
					gen shared_unemp_lag1_old=shared_unemp_lag1;
					
						/* change back previously shocked data */
					replace fgdp_gr_lag1 = fgdp_gr_lag1_old;

/* ****** ADD A ONE STANDARD DEVIATION INCREASE TO EACH OBSERVATION ****** */

					replace shared_unemp_lag1 = shared_unemp_lag1_old+sd_shared_unemp_lag1;
predict count_shared_unemp_lag1_sd;

/* ****** DETERMINE THE MEDIAN NUMBER OF INITIATIONS FOR EACH EXPERIMENT ****** */
collapse (median) all_init_prod ad_init_prod count_median count_pchg_rxr_yoy_lag1_sd count_chg_unemp_yoy_lag1_sd count_fgdp_gr_lag1_sd count_shared_unemp_lag1_sd;


	/* *** PREDICTION:  *** */
list all_init_prod ad_init_prod count_median count_pchg_rxr_yoy_lag1_sd count_chg_unemp_yoy_lag1_sd count_fgdp_gr_lag1_sd count_shared_unemp_lag1_sd;
/* ************************************************************************* */

/* *********** */
/* 7. BASELINE, INCLUDE WTO TARIFFS VARIABLE AND STOCK VARIABLE (TIME SAMPLE GETS RESTRICTED) */
/* *********** */
#delimit;
clear;
use data\quarterly_bilateral\quarterly_bi_INDUSTRIALIZED-5.dta;
keep if twithin(1996-1,2008-4);



xi: nbreg all_init_prod  pchg_rxr_yoy_lag1  chg_unemp_yoy_lag1 fgdp_gr_lag1	quarter chg_zero_fraction_lag1 all_stock_prod_lag1
	i.cty_partner, nolog irr ;

/* ************************************************************************* */
/* ALGORITHM: PREDICT THE NUMBER OF INITIATIONS IN RESPONSE TO A ONE STANDARD DEVIATION CHANGE IN EACH VARIABLE OF INTEREST */
/* PRE CRISIS SAMPLE OF DATA: 1988:Q1-2008:Q3 */

keep if e(sample)==1;
summarize all_init_prod ad_init_prod pchg_rxr_yoy_lag1 chg_unemp_yoy_lag1 rgdp_gr_lag1 fgdp_gr_lag1 chg_zero_fraction_lag1 all_stock_prod_lag1;
	
predict count_median;

 egen sd_pchg_rxr_yoy_lag1=sd(pchg_rxr_yoy_lag1);
 egen sd_chg_unemp_yoy_lag1=sd(chg_unemp_yoy_lag1);
 egen sd_fgdp_gr_lag1=sd(fgdp_gr_lag1);
 egen sd_chg_zero_fraction_lag1=sd(chg_zero_fraction_lag1); 
 egen sd_all_stock_prod_lag1=sd(all_stock_prod_lag1); 
 
/*	MEAN + ONE STANDARD DEVIATION INCREASE IN RXR */

						/* save versions of the old data to change back for the other shocks */
					gen pchg_rxr_yoy_lag1_old=pchg_rxr_yoy_lag1;

/* ****** ADD A ONE STANDARD DEVIATION INCREASE TO EACH OBSERVATION ****** */

					replace pchg_rxr_yoy_lag1 = pchg_rxr_yoy_lag1_old+sd_pchg_rxr_yoy_lag1;
predict count_pchg_rxr_yoy_lag1_sd;



/*	MEAN + ONE STANDARD DEVIATION INCREASE IN DOMESTIC UNEMPLOYMENT RATE */

						/* save versions of the old data to change back for the other shocks */
					gen chg_unemp_yoy_lag1_old=chg_unemp_yoy_lag1;
					
						/* change back previously shocked data */
					replace pchg_rxr_yoy_lag1=pchg_rxr_yoy_lag1_old;

/* ****** ADD A ONE STANDARD DEVIATION INCREASE TO EACH OBSERVATION ****** */

					replace chg_unemp_yoy_lag1 = chg_unemp_yoy_lag1_old+sd_chg_unemp_yoy_lag1;
predict count_chg_unemp_yoy_lag1_sd;

					
/*	MEAN + ONE STANDARD DEVIATION DECREASE IN FOREIGN REAL GDP */

						/* save versions of the old data to change back for the other shocks */
					gen fgdp_gr_lag1_old=fgdp_gr_lag1;

						/* change back previously shocked data */
					replace chg_unemp_yoy_lag1=chg_unemp_yoy_lag1_old;

/* ****** SUBTRACT A ONE STANDARD DEVIATION CHANGE FROM EACH OBSERVATION ****** */

					replace fgdp_gr_lag1 = fgdp_gr_lag1_old-sd_fgdp_gr_lag1;
predict count_fgdp_gr_lag1_sd;


/*	MEAN + ONE STANDARD DEVIATION INCREASE IN IMPORT TARIFF */

						/* save versions of the old data to change back for the other shocks */
					gen chg_zero_fraction_lag1_old=chg_zero_fraction_lag1;
					
						/* change back previously shocked data */
					replace fgdp_gr_lag1 = fgdp_gr_lag1_old;

/* ****** ADD A ONE STANDARD DEVIATION INCREASE TO EACH OBSERVATION ****** */

					replace chg_zero_fraction_lag1 = chg_zero_fraction_lag1_old+sd_chg_zero_fraction_lag1;
predict count_chg_zero_fraction_lag1_sd;


/*	MEAN + ONE STANDARD DEVIATION INCREASE IN ALL STOCK */

						/* save versions of the old data to change back for the other shocks */
					gen all_stock_prod_lag1_old=all_stock_prod_lag1;
					
						/* change back previously shocked data */
					replace chg_zero_fraction_lag1 = chg_zero_fraction_lag1_old;

/* ****** ADD A ONE STANDARD DEVIATION INCREASE TO EACH OBSERVATION ****** */

					replace all_stock_prod_lag1 = all_stock_prod_lag1_old+sd_all_stock_prod_lag1;
predict count_all_stock_prod_lag1_sd;

/* ****** DETERMINE THE MEDIAN NUMBER OF INITIATIONS FOR EACH EXPERIMENT ****** */
collapse (median) all_init_prod ad_init_prod count_median count_pchg_rxr_yoy_lag1_sd count_chg_unemp_yoy_lag1_sd count_fgdp_gr_lag1_sd count_chg_zero_fraction_lag1_sd count_all_stock_prod_lag1_sd;


	/* *** PREDICTION:  *** */
list all_init_prod ad_init_prod count_median count_pchg_rxr_yoy_lag1_sd count_chg_unemp_yoy_lag1_sd count_fgdp_gr_lag1_sd count_chg_zero_fraction_lag1_sd count_all_stock_prod_lag1_sd;
/* ************************************************************************* */

	
	
/* *********** */
/* 8. RE-ESTIMATED ON THAT SUBSAMPLE W/O TARIFF VARIABLES AND STOCK -- SIZE OF MACRO VARIABLES ROUGHLY UNCHANGED */
/* *********** */
#delimit;
clear;
use data\quarterly_bilateral\quarterly_bi_INDUSTRIALIZED-5.dta;
keep if twithin(1996-1,2008-4);

	/* RUN ON SAME SUBSAMPLE AS 7. */
	
	xi: nbreg all_init_prod  pchg_rxr_yoy_lag1  chg_unemp_yoy_lag1 fgdp_gr_lag1	quarter chg_zero_fraction_lag1 all_stock_prod_lag1
	i.cty_partner, nolog irr ;

	keep if e(sample)==1;

	
	/* HERE IS THE ONE WE ARE INTERESTED IN */
	
xi: nbreg all_init_prod   pchg_rxr_yoy_lag1  chg_unemp_yoy_lag1 fgdp_gr_lag1 quarter
	i.cty_partner, nolog irr ;


/* ************************************************************************* */
/* ALGORITHM: PREDICT THE NUMBER OF INITIATIONS IN RESPONSE TO A ONE STANDARD DEVIATION CHANGE IN EACH VARIABLE OF INTEREST */
/* PRE CRISIS SAMPLE OF DATA: 1988:Q1-2008:Q3 */

keep if e(sample)==1;
summarize all_init_prod ad_init_prod pchg_rxr_yoy_lag1 chg_unemp_yoy_lag1 rgdp_gr_lag1 fgdp_gr_lag1;
	
predict count_median;

 egen sd_pchg_rxr_yoy_lag1=sd(pchg_rxr_yoy_lag1);
 egen sd_chg_unemp_yoy_lag1=sd(chg_unemp_yoy_lag1);
 egen sd_fgdp_gr_lag1=sd(fgdp_gr_lag1);

 
/*	MEAN + ONE STANDARD DEVIATION INCREASE IN RXR */

						/* save versions of the old data to change back for the other shocks */
					gen pchg_rxr_yoy_lag1_old=pchg_rxr_yoy_lag1;

/* ****** ADD A ONE STANDARD DEVIATION INCREASE TO EACH OBSERVATION ****** */

					replace pchg_rxr_yoy_lag1 = pchg_rxr_yoy_lag1_old+sd_pchg_rxr_yoy_lag1;
predict count_pchg_rxr_yoy_lag1_sd;



/*	MEAN + ONE STANDARD DEVIATION INCREASE IN DOMESTIC UNEMPLOYMENT RATE */

						/* save versions of the old data to change back for the other shocks */
					gen chg_unemp_yoy_lag1_old=chg_unemp_yoy_lag1;
					
						/* change back previously shocked data */
					replace pchg_rxr_yoy_lag1=pchg_rxr_yoy_lag1_old;

/* ****** ADD A ONE STANDARD DEVIATION INCREASE TO EACH OBSERVATION ****** */

					replace chg_unemp_yoy_lag1 = chg_unemp_yoy_lag1_old+sd_chg_unemp_yoy_lag1;
predict count_chg_unemp_yoy_lag1_sd;

					
/*	MEAN + ONE STANDARD DEVIATION DECREASE IN FOREIGN REAL GDP */

						/* save versions of the old data to change back for the other shocks */
					gen fgdp_gr_lag1_old=fgdp_gr_lag1;

						/* change back previously shocked data */
					replace chg_unemp_yoy_lag1=chg_unemp_yoy_lag1_old;

/* ****** SUBTRACT A ONE STANDARD DEVIATION CHANGE FROM EACH OBSERVATION ****** */

					replace fgdp_gr_lag1 = fgdp_gr_lag1_old-sd_fgdp_gr_lag1;
predict count_fgdp_gr_lag1_sd;

/* ****** DETERMINE THE MEDIAN NUMBER OF INITIATIONS FOR EACH EXPERIMENT ****** */
collapse (median) all_init_prod ad_init_prod count_median count_pchg_rxr_yoy_lag1_sd count_chg_unemp_yoy_lag1_sd count_fgdp_gr_lag1_sd;

	/* *** PREDICTION:  *** */
list all_init_prod ad_init_prod count_median count_pchg_rxr_yoy_lag1_sd count_chg_unemp_yoy_lag1_sd count_fgdp_gr_lag1_sd;
/* ************************************************************************* */
	
log close;

