/*	Author :	Chad P. Bown & Meredith A. Crowley						*/
/*	Date : 	27 October 2011												*/
/*	Revised :	8 August 2012											*/
/*	Desc : 		Bown-Crowley macro determinants, Table 3				*/
/*	Input :	data\quarterly_bilateral\quarterly_bi_INDUSTRIALIZED-5.dta 	*/
/*	Output :															*/ 
/*																		*/
/*	Next :																*/

clear
set mem 750m

version 7.0
#delimit ;
set more off;

cd MY_PATH;

log using data\quarterly_bilateral\Table-3-08-08-2012, replace;


/* TABLE 3 */
/* 1988:Q1-2008:Q3: Pre-crisis sample of data, baseline specification and robustness checks */


/* ************ USA ************* */


/* *********** */
/* 1. BASELINE */
/* *********** */
clear;
use data\quarterly_bilateral\quarterly_bi_INDUSTRIALIZED-5.dta;
keep if twithin(1987-4,2008-4);
keep if cty_code=="USA";

xi: nbreg all_init_prod  pchg_rxr_yoy_lag1 chg_unemp_yoy_lag1 fgdp_gr_lag1 quarter partner_CHN
	i.cty_partner, nolog irr ;

/* ************************************************************************* */
/* ALGORITHM: PREDICT THE NUMBER OF INITIATIONS IN RESPONSE TO A ONE STANDARD DEVIATION CHANGE 
IN EACH VARIABLE OF INTEREST */
/* PRE CRISIS SAMPLE OF DATA: 1988:Q1-2008:Q3 */

keep if e(sample)==1;
summarize all_init_prod ad_init_prod pchg_rxr_yoy_lag1 chg_unemp_yoy_lag1 rgdp_gr_lag1 fgdp_gr_lag1;
	
predict count_median;

 egen sd_pchg_rxr_yoy_lag1=sd(pchg_rxr_yoy_lag1);
 egen sd_chg_unemp_yoy_lag1=sd(chg_unemp_yoy_lag1);
 egen sd_fgdp_gr_lag1=sd(fgdp_gr_lag1);
 

/*	MEAN + ONE STANDARD DEVIATION INCREASE IN RXR */

						/* save versions of the old data to change back for the other shocks */
					gen pchg_rxr_yoy_lag1_old=pchg_rxr_yoy_lag1;

/* ****** ADD ONE STANDARD DEVIATION INCREASE TO EACH OBSERVATION ****** */

					replace pchg_rxr_yoy_lag1 = pchg_rxr_yoy_lag1_old+sd_pchg_rxr_yoy_lag1;
predict count_pchg_rxr_yoy_lag1_sd;



/*	MEAN + ONE STANDARD DEVIATION INCREASE IN DOMESTIC UNEMPLOYMENT RATE */

						/* save versions of the old data to change back for the other shocks */
					gen chg_unemp_yoy_lag1_old=chg_unemp_yoy_lag1;
					
						/* change back previously shocked data */
					replace pchg_rxr_yoy_lag1=pchg_rxr_yoy_lag1_old;

/* ****** ADD ONE STANDARD DEVIATION INCREASE TO EACH OBSERVATION ****** */

					replace chg_unemp_yoy_lag1 = chg_unemp_yoy_lag1_old+sd_chg_unemp_yoy_lag1;
predict count_chg_unemp_yoy_lag1_sd;

					
/*	MEAN + ONE STANDARD DEVIATION DECREASE IN FOREIGN REAL GDP */

						/* save versions of the old data to change back for the other shocks */
					gen fgdp_gr_lag1_old=fgdp_gr_lag1;

						/* change back previously shocked data */
					replace chg_unemp_yoy_lag1=chg_unemp_yoy_lag1_old;

/* ****** SUBTRACT A ONE STANDARD DEVIATION CHANGE FROM EACH OBSERVATION ****** */

					replace fgdp_gr_lag1 = fgdp_gr_lag1_old-sd_fgdp_gr_lag1;
predict count_fgdp_gr_lag1_sd;

/* ****** DETERMINE THE MEDIAN NUMBER OF INITIATIONS FOR EACH EXPERIMENT ****** */

collapse (median) all_init_prod ad_init_prod count_median count_pchg_rxr_yoy_lag1_sd count_chg_unemp_yoy_lag1_sd count_fgdp_gr_lag1_sd ;


	/* *** PREDICTION:  *** */
list all_init_prod ad_init_prod count_median count_pchg_rxr_yoy_lag1_sd count_chg_unemp_yoy_lag1_sd count_fgdp_gr_lag1_sd ;
/* ************************************************************************* */
	
	

/* *********** */
/* 2. ALL TTBS: USE 2nd LAG INSTEAD OF 1st */
/* *********** */
clear;
use data\quarterly_bilateral\quarterly_bi_INDUSTRIALIZED-5.dta;
keep if twithin(1987-4,2008-4);
keep if cty_code=="USA";

xi: nbreg all_init_prod  pchg_rxr_yoy_lag2 chg_unemp_yoy_lag2 fgdp_gr_lag2 quarter partner_CHN
	i.cty_partner, nolog irr ;

/* ************************************************************************* */
/* ALGORITHM: PREDICT THE NUMBER OF INITIATIONS IN RESPONSE TO A ONE STANDARD DEVIATION CHANGE 
IN EACH VARIABLE OF INTEREST */
/* PRE CRISIS SAMPLE OF DATA: 1988:Q1-2008:Q3 */

keep if e(sample)==1;
summarize all_init_prod ad_init_prod pchg_rxr_yoy_lag2 chg_unemp_yoy_lag2 rgdp_gr_lag2 fgdp_gr_lag2;
	
predict count_median;

 egen sd_pchg_rxr_yoy_lag2=sd(pchg_rxr_yoy_lag2);
 egen sd_chg_unemp_yoy_lag2=sd(chg_unemp_yoy_lag2);
 egen sd_fgdp_gr_lag2=sd(fgdp_gr_lag2);
 
/*	MEAN + ONE STANDARD DEVIATION INCREASE IN RXR */

						/* save versions of the old data to change back for the other shocks */
					gen pchg_rxr_yoy_lag2_old=pchg_rxr_yoy_lag2;

/* ****** ADD ONE STANDARD DEVIATION INCREASE TO EACH OBSERVATION ****** */

					replace pchg_rxr_yoy_lag2 = pchg_rxr_yoy_lag2_old+sd_pchg_rxr_yoy_lag2;
predict count_pchg_rxr_yoy_lag2_sd;



/*	MEAN + ONE STANDARD DEVIATION INCREASE IN DOMESTIC UNEMPLOYMENT RATE */

						/* save versions of the old data to change back for the other shocks */
					gen chg_unemp_yoy_lag2_old=chg_unemp_yoy_lag2;
					
						/* change back previously shocked data */
					replace pchg_rxr_yoy_lag2=pchg_rxr_yoy_lag2_old;

/* ****** ADD ONE STANDARD DEVIATION INCREASE TO EACH OBSERVATION ****** */

					replace chg_unemp_yoy_lag2 = chg_unemp_yoy_lag2_old+sd_chg_unemp_yoy_lag2;
predict count_chg_unemp_yoy_lag2_sd;

					
/*	MEAN + ONE STANDARD DEVIATION DECREASE IN FOREIGN REAL GDP */

						/* save versions of the old data to change back for the other shocks */
					gen fgdp_gr_lag2_old=fgdp_gr_lag2;

						/* change back previously shocked data */
					replace chg_unemp_yoy_lag2=chg_unemp_yoy_lag2_old;

/* ****** SUBTRACT A ONE STANDARD DEVIATION CHANGE FROM EACH OBSERVATION ****** */

					replace fgdp_gr_lag2 = fgdp_gr_lag2_old-sd_fgdp_gr_lag2;
predict count_fgdp_gr_lag2_sd;

/* ****** DETERMINE THE MEDIAN NUMBER OF INITIATIONS FOR EACH EXPERIMENT ****** */

collapse (median) all_init_prod ad_init_prod count_median count_pchg_rxr_yoy_lag2_sd count_chg_unemp_yoy_lag2_sd count_fgdp_gr_lag2_sd ;


	/* *** PREDICTION:  *** */
list all_init_prod ad_init_prod count_median count_pchg_rxr_yoy_lag2_sd count_chg_unemp_yoy_lag2_sd count_fgdp_gr_lag2_sd ;
/* ************************************************************************* */
	
	

/* *********** */
/* 3. BASELINE: USE AD, NOT ALL TTBS */
/* *********** */
clear;
use data\quarterly_bilateral\quarterly_bi_INDUSTRIALIZED-5.dta;
keep if twithin(1987-4,2008-4);
keep if cty_code=="USA";

xi: nbreg ad_init_prod  pchg_rxr_yoy_lag1 chg_unemp_yoy_lag1 fgdp_gr_lag1 quarter partner_CHN
	i.cty_partner, nolog irr ;

/* ************************************************************************* */
/* ALGORITHM: PREDICT THE NUMBER OF INITIATIONS IN RESPONSE TO A ONE STANDARD DEVIATION CHANGE 
IN EACH VARIABLE OF INTEREST */
/* PRE CRISIS SAMPLE OF DATA: 1988:Q1-2008:Q3 */

keep if e(sample)==1;
summarize all_init_prod ad_init_prod pchg_rxr_yoy_lag1 chg_unemp_yoy_lag1 rgdp_gr_lag1 fgdp_gr_lag1;
	
predict count_median;

 egen sd_pchg_rxr_yoy_lag1=sd(pchg_rxr_yoy_lag1);
 egen sd_chg_unemp_yoy_lag1=sd(chg_unemp_yoy_lag1);
 egen sd_fgdp_gr_lag1=sd(fgdp_gr_lag1);
 

/*	MEAN + ONE STANDARD DEVIATION INCREASE IN RXR */

						/* save versions of the old data to change back for the other shocks */
					gen pchg_rxr_yoy_lag1_old=pchg_rxr_yoy_lag1;

/* ****** ADD ONE STANDARD DEVIATION INCREASE TO EACH OBSERVATION ****** */

					replace pchg_rxr_yoy_lag1 = pchg_rxr_yoy_lag1_old+sd_pchg_rxr_yoy_lag1;
predict count_pchg_rxr_yoy_lag1_sd;



/*	MEAN + ONE STANDARD DEVIATION INCREASE IN DOMESTIC UNEMPLOYMENT RATE */

						/* save versions of the old data to change back for the other shocks */
					gen chg_unemp_yoy_lag1_old=chg_unemp_yoy_lag1;
					
						/* change back previously shocked data */
					replace pchg_rxr_yoy_lag1=pchg_rxr_yoy_lag1_old;

/* ****** ADD ONE STANDARD DEVIATION INCREASE TO EACH OBSERVATION ****** */

					replace chg_unemp_yoy_lag1 = chg_unemp_yoy_lag1_old+sd_chg_unemp_yoy_lag1;
predict count_chg_unemp_yoy_lag1_sd;

					
/*	MEAN + ONE STANDARD DEVIATION DECREASE IN FOREIGN REAL GDP */

						/* save versions of the old data to change back for the other shocks */
					gen fgdp_gr_lag1_old=fgdp_gr_lag1;

						/* change back previously shocked data */
					replace chg_unemp_yoy_lag1=chg_unemp_yoy_lag1_old;

/* ****** SUBTRACT A ONE STANDARD DEVIATION CHANGE FROM EACH OBSERVATION ****** */

					replace fgdp_gr_lag1 = fgdp_gr_lag1_old-sd_fgdp_gr_lag1;
predict count_fgdp_gr_lag1_sd;

/* ****** DETERMINE THE MEDIAN NUMBER OF INITIATIONS FOR EACH EXPERIMENT ****** */

collapse (median) all_init_prod ad_init_prod count_median count_pchg_rxr_yoy_lag1_sd count_chg_unemp_yoy_lag1_sd count_fgdp_gr_lag1_sd ;


	/* *** PREDICTION:  *** */
list all_init_prod ad_init_prod count_median count_pchg_rxr_yoy_lag1_sd count_chg_unemp_yoy_lag1_sd count_fgdp_gr_lag1_sd ;
/* ************************************************************************* */
	
	

/* ************ EUN ************* */


/* *********** */
/* 1. BASELINE */
/* *********** */
#delimit;
clear;
use data\quarterly_bilateral\quarterly_bi_INDUSTRIALIZED-5.dta;
keep if twithin(1998-4,2008-4);

keep if cty_code=="EUN";


xi: nbreg all_init_prod  pchg_rxr_yoy_lag1 chg_unemp_yoy_lag1 fgdp_gr_lag1 quarter partner_CHN
	i.cty_partner, nolog irr ;

/* ************************************************************************* */
/* ALGORITHM: PREDICT THE NUMBER OF INITIATIONS IN RESPONSE TO A ONE STANDARD DEVIATION CHANGE 
IN EACH VARIABLE OF INTEREST */
/* PRE CRISIS SAMPLE OF DATA: 1988:Q1-2008:Q3 */

keep if e(sample)==1;
summarize all_init_prod ad_init_prod pchg_rxr_yoy_lag1 chg_unemp_yoy_lag1 rgdp_gr_lag1 fgdp_gr_lag1;
	
predict count_median;

 egen sd_pchg_rxr_yoy_lag1=sd(pchg_rxr_yoy_lag1);
 egen sd_chg_unemp_yoy_lag1=sd(chg_unemp_yoy_lag1);
 egen sd_fgdp_gr_lag1=sd(fgdp_gr_lag1);

/*	MEAN + ONE STANDARD DEVIATION INCREASE IN RXR */

						/* save versions of the old data to change back for the other shocks */
					gen pchg_rxr_yoy_lag1_old=pchg_rxr_yoy_lag1;

/* ****** ADD ONE STANDARD DEVIATION INCREASE TO EACH OBSERVATION ****** */

					replace pchg_rxr_yoy_lag1 = pchg_rxr_yoy_lag1_old+sd_pchg_rxr_yoy_lag1;
predict count_pchg_rxr_yoy_lag1_sd;



/*	MEAN + ONE STANDARD DEVIATION INCREASE IN DOMESTIC UNEMPLOYMENT RATE */

						/* save versions of the old data to change back for the other shocks */
					gen chg_unemp_yoy_lag1_old=chg_unemp_yoy_lag1;
					
						/* change back previously shocked data */
					replace pchg_rxr_yoy_lag1=pchg_rxr_yoy_lag1_old;

/* ****** ADD ONE STANDARD DEVIATION INCREASE TO EACH OBSERVATION ****** */

					replace chg_unemp_yoy_lag1 = chg_unemp_yoy_lag1_old+sd_chg_unemp_yoy_lag1;
predict count_chg_unemp_yoy_lag1_sd;

					
/*	MEAN + ONE STANDARD DEVIATION DECREASE IN FOREIGN REAL GDP */

						/* save versions of the old data to change back for the other shocks */
					gen fgdp_gr_lag1_old=fgdp_gr_lag1;

						/* change back previously shocked data */
					replace chg_unemp_yoy_lag1=chg_unemp_yoy_lag1_old;

/* ****** SUBTRACT A ONE STANDARD DEVIATION CHANGE FROM EACH OBSERVATION ****** */

					replace fgdp_gr_lag1 = fgdp_gr_lag1_old-sd_fgdp_gr_lag1;
predict count_fgdp_gr_lag1_sd;

/* ****** DETERMINE THE MEDIAN NUMBER OF INITIATIONS FOR EACH EXPERIMENT ****** */

collapse (median) all_init_prod ad_init_prod count_median count_pchg_rxr_yoy_lag1_sd count_chg_unemp_yoy_lag1_sd count_fgdp_gr_lag1_sd ;


	/* *** PREDICTION:  *** */
list all_init_prod ad_init_prod count_median count_pchg_rxr_yoy_lag1_sd count_chg_unemp_yoy_lag1_sd count_fgdp_gr_lag1_sd ;
/* ************************************************************************* */

/* *********** */
/* 2. ALL TTBS: USE 2nd LAG INSTEAD OF 1st */
/* *********** */
#delimit;
clear;
use data\quarterly_bilateral\quarterly_bi_INDUSTRIALIZED-5.dta;
keep if twithin(1998-4,2008-4);

keep if cty_code=="EUN";

xi: nbreg all_init_prod  pchg_rxr_yoy_lag2 chg_unemp_yoy_lag2 fgdp_gr_lag2 quarter partner_CHN
	i.cty_partner, nolog irr ;

/* ************************************************************************* */
/* ALGORITHM: PREDICT THE NUMBER OF INITIATIONS IN RESPONSE TO A ONE STANDARD DEVIATION CHANGE 
IN EACH VARIABLE OF INTEREST */
/* PRE CRISIS SAMPLE OF DATA: 1988:Q1-2008:Q3 */

keep if e(sample)==1;
summarize all_init_prod ad_init_prod pchg_rxr_yoy_lag2 chg_unemp_yoy_lag2 rgdp_gr_lag2 fgdp_gr_lag2;
	
predict count_median;

 egen sd_pchg_rxr_yoy_lag2=sd(pchg_rxr_yoy_lag2);
 egen sd_chg_unemp_yoy_lag2=sd(chg_unemp_yoy_lag2);
 egen sd_fgdp_gr_lag2=sd(fgdp_gr_lag2);

/*	MEAN + ONE STANDARD DEVIATION INCREASE IN RXR */

						/* save versions of the old data to change back for the other shocks */
					gen pchg_rxr_yoy_lag2_old=pchg_rxr_yoy_lag2;

/* ****** ADD ONE STANDARD DEVIATION INCREASE TO EACH OBSERVATION ****** */

					replace pchg_rxr_yoy_lag2 = pchg_rxr_yoy_lag2_old+sd_pchg_rxr_yoy_lag2;
predict count_pchg_rxr_yoy_lag2_sd;



/*	MEAN + ONE STANDARD DEVIATION INCREASE IN DOMESTIC UNEMPLOYMENT RATE */

						/* save versions of the old data to change back for the other shocks */
					gen chg_unemp_yoy_lag2_old=chg_unemp_yoy_lag2;
					
						/* change back previously shocked data */
					replace pchg_rxr_yoy_lag2=pchg_rxr_yoy_lag2_old;

/* ****** ADD ONE STANDARD DEVIATION INCREASE TO EACH OBSERVATION ****** */

					replace chg_unemp_yoy_lag2 = chg_unemp_yoy_lag2_old+sd_chg_unemp_yoy_lag2;
predict count_chg_unemp_yoy_lag2_sd;

					
/*	MEAN + ONE STANDARD DEVIATION DECREASE IN FOREIGN REAL GDP */

						/* save versions of the old data to change back for the other shocks */
					gen fgdp_gr_lag2_old=fgdp_gr_lag2;

						/* change back previously shocked data */
					replace chg_unemp_yoy_lag2=chg_unemp_yoy_lag2_old;

/* ****** SUBTRACT A ONE STANDARD DEVIATION CHANGE FROM EACH OBSERVATION ****** */

					replace fgdp_gr_lag2 = fgdp_gr_lag2_old-sd_fgdp_gr_lag2;
predict count_fgdp_gr_lag2_sd;

/* ****** DETERMINE THE MEDIAN NUMBER OF INITIATIONS FOR EACH EXPERIMENT ****** */

collapse (median) all_init_prod ad_init_prod count_median count_pchg_rxr_yoy_lag2_sd count_chg_unemp_yoy_lag2_sd count_fgdp_gr_lag2_sd ;


	/* *** PREDICTION:  *** */
list all_init_prod ad_init_prod count_median count_pchg_rxr_yoy_lag2_sd count_chg_unemp_yoy_lag2_sd count_fgdp_gr_lag2_sd ;
/* ************************************************************************* */

	

/* *********** */
/* 3. BASELINE: USE AD, NOT ALL TTBS */
/* *********** */
#delimit;
clear;
use data\quarterly_bilateral\quarterly_bi_INDUSTRIALIZED-5.dta;
keep if twithin(1998-4,2008-4);

keep if cty_code=="EUN";

xi: nbreg ad_init_prod  pchg_rxr_yoy_lag1 chg_unemp_yoy_lag1 fgdp_gr_lag1 quarter partner_CHN
	i.cty_partner, nolog irr ;

/* ************************************************************************* */
/* ALGORITHM: PREDICT THE NUMBER OF INITIATIONS IN RESPONSE TO A ONE STANDARD DEVIATION CHANGE 
IN EACH VARIABLE OF INTEREST */
/* PRE CRISIS SAMPLE OF DATA: 1988:Q1-2008:Q3 */

keep if e(sample)==1;
summarize all_init_prod ad_init_prod pchg_rxr_yoy_lag1 chg_unemp_yoy_lag1 rgdp_gr_lag1 fgdp_gr_lag1;
	
predict count_median;

 egen sd_pchg_rxr_yoy_lag1=sd(pchg_rxr_yoy_lag1);
 egen sd_chg_unemp_yoy_lag1=sd(chg_unemp_yoy_lag1);
 egen sd_fgdp_gr_lag1=sd(fgdp_gr_lag1);

/*	MEAN + ONE STANDARD DEVIATION INCREASE IN RXR */

						/* save versions of the old data to change back for the other shocks */
					gen pchg_rxr_yoy_lag1_old=pchg_rxr_yoy_lag1;

/* ****** ADD ONE STANDARD DEVIATION INCREASE TO EACH OBSERVATION ****** */

					replace pchg_rxr_yoy_lag1 = pchg_rxr_yoy_lag1_old+sd_pchg_rxr_yoy_lag1;
predict count_pchg_rxr_yoy_lag1_sd;



/*	MEAN + ONE STANDARD DEVIATION INCREASE IN DOMESTIC UNEMPLOYMENT RATE */

						/* save versions of the old data to change back for the other shocks */
					gen chg_unemp_yoy_lag1_old=chg_unemp_yoy_lag1;
					
						/* change back previously shocked data */
					replace pchg_rxr_yoy_lag1=pchg_rxr_yoy_lag1_old;

/* ****** ADD ONE STANDARD DEVIATION INCREASE TO EACH OBSERVATION ****** */

					replace chg_unemp_yoy_lag1 = chg_unemp_yoy_lag1_old+sd_chg_unemp_yoy_lag1;
predict count_chg_unemp_yoy_lag1_sd;

					
/*	MEAN + ONE STANDARD DEVIATION DECREASE IN FOREIGN REAL GDP */

						/* save versions of the old data to change back for the other shocks */
					gen fgdp_gr_lag1_old=fgdp_gr_lag1;

						/* change back previously shocked data */
					replace chg_unemp_yoy_lag1=chg_unemp_yoy_lag1_old;

/* ****** SUBTRACT A ONE STANDARD DEVIATION CHANGE FROM EACH OBSERVATION ****** */

					replace fgdp_gr_lag1 = fgdp_gr_lag1_old-sd_fgdp_gr_lag1;
predict count_fgdp_gr_lag1_sd;

/* ****** DETERMINE THE MEDIAN NUMBER OF INITIATIONS FOR EACH EXPERIMENT ****** */

collapse (median) all_init_prod ad_init_prod count_median count_pchg_rxr_yoy_lag1_sd count_chg_unemp_yoy_lag1_sd count_fgdp_gr_lag1_sd ;


	/* *** PREDICTION:  *** */
list all_init_prod ad_init_prod count_median count_pchg_rxr_yoy_lag1_sd count_chg_unemp_yoy_lag1_sd count_fgdp_gr_lag1_sd ;
/* ************************************************************************* */



/* ************ AUS, CAN, KOR ************* */
/* *********** */
/* 1. BASELINE */
/* *********** */

#delimit;
clear;
use data\quarterly_bilateral\quarterly_bi_INDUSTRIALIZED-5.dta;
keep if twithin(1987-4,2008-4);

keep if cty_code=="AUS" | cty_code=="CAN" | cty_code=="KOR";


xi: nbreg all_init_prod  pchg_rxr_yoy_lag1 chg_unemp_yoy_lag1 fgdp_gr_lag1 quarter partner_CHN
	i.cty_partner, nolog irr ;

/* ************************************************************************* */
/* ALGORITHM: PREDICT THE NUMBER OF INITIATIONS IN RESPONSE TO A ONE STANDARD DEVIATION CHANGE 
IN EACH VARIABLE OF INTEREST */
/* PRE CRISIS SAMPLE OF DATA: 1988:Q1-2008:Q3 */

keep if e(sample)==1;
summarize all_init_prod ad_init_prod pchg_rxr_yoy_lag1 chg_unemp_yoy_lag1 rgdp_gr_lag1 fgdp_gr_lag1;
	
predict count_median;

 egen sd_pchg_rxr_yoy_lag1=sd(pchg_rxr_yoy_lag1);
 egen sd_chg_unemp_yoy_lag1=sd(chg_unemp_yoy_lag1);
 egen sd_fgdp_gr_lag1=sd(fgdp_gr_lag1);

/*	MEAN + ONE STANDARD DEVIATION INCREASE IN RXR */

						/* save versions of the old data to change back for the other shocks */
					gen pchg_rxr_yoy_lag1_old=pchg_rxr_yoy_lag1;

/* ****** ADD ONE STANDARD DEVIATION INCREASE TO EACH OBSERVATION ****** */

					replace pchg_rxr_yoy_lag1 = pchg_rxr_yoy_lag1_old+sd_pchg_rxr_yoy_lag1;
predict count_pchg_rxr_yoy_lag1_sd;



/*	MEAN + ONE STANDARD DEVIATION INCREASE IN DOMESTIC UNEMPLOYMENT RATE */

						/* save versions of the old data to change back for the other shocks */
					gen chg_unemp_yoy_lag1_old=chg_unemp_yoy_lag1;
					
						/* change back previously shocked data */
					replace pchg_rxr_yoy_lag1=pchg_rxr_yoy_lag1_old;

/* ****** ADD ONE STANDARD DEVIATION INCREASE TO EACH OBSERVATION ****** */

					replace chg_unemp_yoy_lag1 = chg_unemp_yoy_lag1_old+sd_chg_unemp_yoy_lag1;
predict count_chg_unemp_yoy_lag1_sd;

					
/*	MEAN + ONE STANDARD DEVIATION DECREASE IN FOREIGN REAL GDP */

						/* save versions of the old data to change back for the other shocks */
					gen fgdp_gr_lag1_old=fgdp_gr_lag1;

						/* change back previously shocked data */
					replace chg_unemp_yoy_lag1=chg_unemp_yoy_lag1_old;

/* ****** SUBTRACT A ONE STANDARD DEVIATION CHANGE FROM EACH OBSERVATION ****** */

					replace fgdp_gr_lag1 = fgdp_gr_lag1_old-sd_fgdp_gr_lag1;
predict count_fgdp_gr_lag1_sd;

/* ****** DETERMINE THE MEDIAN NUMBER OF INITIATIONS FOR EACH EXPERIMENT ****** */

collapse (median) all_init_prod ad_init_prod count_median count_pchg_rxr_yoy_lag1_sd count_chg_unemp_yoy_lag1_sd count_fgdp_gr_lag1_sd ;


	/* *** PREDICTION:  *** */
list all_init_prod ad_init_prod count_median count_pchg_rxr_yoy_lag1_sd count_chg_unemp_yoy_lag1_sd count_fgdp_gr_lag1_sd ;
/* ************************************************************************* */


/* *********** */
/* 2. ALL TTBS: USE 2nd LAG INSTEAD OF 1st */
/* *********** */


clear;
use data\quarterly_bilateral\quarterly_bi_INDUSTRIALIZED-5.dta;
keep if twithin(1987-4,2008-4);

keep if cty_code=="AUS" | cty_code=="CAN" | cty_code=="KOR";

xi: nbreg all_init_prod  pchg_rxr_yoy_lag2 chg_unemp_yoy_lag2 fgdp_gr_lag2 quarter partner_CHN
	i.cty_partner, nolog irr ;

/* ************************************************************************* */
/* ALGORITHM: PREDICT THE NUMBER OF INITIATIONS IN RESPONSE TO A ONE STANDARD DEVIATION CHANGE 
IN EACH VARIABLE OF INTEREST */
/* PRE CRISIS SAMPLE OF DATA: 1988:Q1-2008:Q3 */

keep if e(sample)==1;
summarize all_init_prod ad_init_prod pchg_rxr_yoy_lag2 chg_unemp_yoy_lag2 rgdp_gr_lag2 fgdp_gr_lag2;
	
predict count_median;

 egen sd_pchg_rxr_yoy_lag2=sd(pchg_rxr_yoy_lag2);
 egen sd_chg_unemp_yoy_lag2=sd(chg_unemp_yoy_lag2);
 egen sd_fgdp_gr_lag2=sd(fgdp_gr_lag2);

/*	MEAN + ONE STANDARD DEVIATION INCREASE IN RXR */

						/* save versions of the old data to change back for the other shocks */
					gen pchg_rxr_yoy_lag2_old=pchg_rxr_yoy_lag2;

/* ****** ADD ONE STANDARD DEVIATION INCREASE TO EACH OBSERVATION ****** */

					replace pchg_rxr_yoy_lag2 = pchg_rxr_yoy_lag2_old+sd_pchg_rxr_yoy_lag2;
predict count_pchg_rxr_yoy_lag2_sd;



/*	MEAN + ONE STANDARD DEVIATION INCREASE IN DOMESTIC UNEMPLOYMENT RATE */

						/* save versions of the old data to change back for the other shocks */
					gen chg_unemp_yoy_lag2_old=chg_unemp_yoy_lag2;
					
						/* change back previously shocked data */
					replace pchg_rxr_yoy_lag2=pchg_rxr_yoy_lag2_old;

/* ****** ADD ONE STANDARD DEVIATION INCREASE TO EACH OBSERVATION ****** */

					replace chg_unemp_yoy_lag2 = chg_unemp_yoy_lag2_old+sd_chg_unemp_yoy_lag2;
predict count_chg_unemp_yoy_lag2_sd;

					
/*	MEAN + ONE STANDARD DEVIATION DECREASE IN FOREIGN REAL GDP */

						/* save versions of the old data to change back for the other shocks */
					gen fgdp_gr_lag2_old=fgdp_gr_lag2;

						/* change back previously shocked data */
					replace chg_unemp_yoy_lag2=chg_unemp_yoy_lag2_old;

/* ****** SUBTRACT A ONE STANDARD DEVIATION CHANGE FROM EACH OBSERVATION ****** */

					replace fgdp_gr_lag2 = fgdp_gr_lag2_old-sd_fgdp_gr_lag2;
predict count_fgdp_gr_lag2_sd;

/* ****** DETERMINE THE MEDIAN NUMBER OF INITIATIONS FOR EACH EXPERIMENT ****** */

collapse (median) all_init_prod ad_init_prod count_median count_pchg_rxr_yoy_lag2_sd count_chg_unemp_yoy_lag2_sd count_fgdp_gr_lag2_sd ;


	/* *** PREDICTION:  *** */
list all_init_prod ad_init_prod count_median count_pchg_rxr_yoy_lag2_sd count_chg_unemp_yoy_lag2_sd count_fgdp_gr_lag2_sd ;
/* ************************************************************************* */


/* *********** */
/* 3. BASELINE: USE AD, NOT ALL TTBS */
/* *********** */


clear;
use data\quarterly_bilateral\quarterly_bi_INDUSTRIALIZED-5.dta;
keep if twithin(1987-4,2008-4);

keep if cty_code=="AUS" | cty_code=="CAN" | cty_code=="KOR";
xi: nbreg ad_init_prod  pchg_rxr_yoy_lag1 chg_unemp_yoy_lag1 fgdp_gr_lag1 quarter partner_CHN
	i.cty_partner, nolog irr ;

/* ************************************************************************* */
/* ALGORITHM: PREDICT THE NUMBER OF INITIATIONS IN RESPONSE TO A ONE STANDARD DEVIATION CHANGE 
IN EACH VARIABLE OF INTEREST */
/* PRE CRISIS SAMPLE OF DATA: 1988:Q1-2008:Q3 */

keep if e(sample)==1;
summarize all_init_prod ad_init_prod pchg_rxr_yoy_lag1 chg_unemp_yoy_lag1 rgdp_gr_lag1 fgdp_gr_lag1;
	
predict count_median;

 egen sd_pchg_rxr_yoy_lag1=sd(pchg_rxr_yoy_lag1);
 egen sd_chg_unemp_yoy_lag1=sd(chg_unemp_yoy_lag1);
 egen sd_fgdp_gr_lag1=sd(fgdp_gr_lag1);

/*	MEAN + ONE STANDARD DEVIATION INCREASE IN RXR */

						/* save versions of the old data to change back for the other shocks */
					gen pchg_rxr_yoy_lag1_old=pchg_rxr_yoy_lag1;

/* ****** ADD ONE STANDARD DEVIATION INCREASE TO EACH OBSERVATION ****** */

					replace pchg_rxr_yoy_lag1 = pchg_rxr_yoy_lag1_old+sd_pchg_rxr_yoy_lag1;
predict count_pchg_rxr_yoy_lag1_sd;



/*	MEAN + ONE STANDARD DEVIATION INCREASE IN DOMESTIC UNEMPLOYMENT RATE */

						/* save versions of the old data to change back for the other shocks */
					gen chg_unemp_yoy_lag1_old=chg_unemp_yoy_lag1;
					
						/* change back previously shocked data */
					replace pchg_rxr_yoy_lag1=pchg_rxr_yoy_lag1_old;

/* ****** ADD ONE STANDARD DEVIATION INCREASE TO EACH OBSERVATION ****** */

					replace chg_unemp_yoy_lag1 = chg_unemp_yoy_lag1_old+sd_chg_unemp_yoy_lag1;
predict count_chg_unemp_yoy_lag1_sd;

					
/*	MEAN + ONE STANDARD DEVIATION DECREASE IN FOREIGN REAL GDP */

						/* save versions of the old data to change back for the other shocks */
					gen fgdp_gr_lag1_old=fgdp_gr_lag1;

						/* change back previously shocked data */
					replace chg_unemp_yoy_lag1=chg_unemp_yoy_lag1_old;

/* ****** SUBTRACT A ONE STANDARD DEVIATION CHANGE FROM EACH OBSERVATION ****** */

					replace fgdp_gr_lag1 = fgdp_gr_lag1_old-sd_fgdp_gr_lag1;
predict count_fgdp_gr_lag1_sd;

/* ****** DETERMINE THE MEDIAN NUMBER OF INITIATIONS FOR EACH EXPERIMENT ****** */

collapse (median) all_init_prod ad_init_prod count_median count_pchg_rxr_yoy_lag1_sd count_chg_unemp_yoy_lag1_sd count_fgdp_gr_lag1_sd ;


	/* *** PREDICTION:  *** */
list all_init_prod ad_init_prod count_median count_pchg_rxr_yoy_lag1_sd count_chg_unemp_yoy_lag1_sd count_fgdp_gr_lag1_sd ;
/* ************************************************************************* */

		
log close;

