/*	Author :	Chad P. Bown & Meredith A. Crowley									*/
/*	Date : 	27 October 2011															*/
/*	Revised :		8 August 2012													*/
/*	Desc : 	Bown-Crowley macro determinants, Table 4 								*/
/*	Input :	For Table 4:data\quarterly_bilateral\quarterly_bi_INDUSTRIALIZED-5.dta 	*/
/*																					*/
/*	Next :																			*/

clear
set mem 750m

version 7.0
#delimit ;
 set more off;

cd MY_PATH;

log using data\quarterly_bilateral\Tables-4-and-1-08-08-2012, replace;
	
/* TABLE 4: 1988-2010 Pre-crisis vs Post-crisis: All policy initiations */


/* **************** ALL POLICY IMPOSING ECONOMIES ********************** */


/* ************************* */
/* 1. BASELINE: AT ONE LAG */
/* ************************* */

#delimit;
clear;
use data\quarterly_bilateral\quarterly_bi_INDUSTRIALIZED-5.dta;
keep if twithin(1987-4,2011-1);

xi: nbreg all_init_prod   pchg_rxr_yoy_lag1_pre 
	pchg_rxr_yoy_lag1_post
	chg_unemp_yoy_lag1_pre
	chg_unemp_yoy_lag1_post
	fgdp_gr_lag1_pre
	fgdp_gr_lag1_post
	 quarter_pre quarter_post
	i.cty_partner, nolog irr ;

/* STRUCTURAL BREAK FOR RXR? */
test((pchg_rxr_yoy_lag1_pre)-(pchg_rxr_yoy_lag1_post))=0;

/* STRUCTURAL BREAK FOR UNEMPLOYMENT CHANGE? */
test((chg_unemp_yoy_lag1_pre)-(chg_unemp_yoy_lag1_post))=0;

/* STRUCTURAL BREAK FOR FOREIGN GDP SHOCK? */
test((fgdp_gr_lag1_pre)-(fgdp_gr_lag1_post))=0;

/* STRUCTURAL BREAK FOR TIME TREND? */
test((quarter_pre)-(quarter_post))=0;


/* ************************* */
/* CREATE SUMMARY STATISTICS FOR TABLE 1 */
/* ************************* */


keep if e(sample)==1;
/*Create a dummy for the pre-crisis to construct summary statistics */
gen pre_crisis=.;
replace pre_crisis=1 if twithin(1987-4,2008-4);

sort pre_crisis;
by pre_crisis: sum all_init_prod ad_init_prod pchg_rxr_yoy chg_unemp_yoy rgdp_gr fgdp_gr imp_gr_yoy;



/* ************************* */
/* 2. AT TWO LAGS */
/* ************************* */

#delimit;
clear;
use data\quarterly_bilateral\quarterly_bi_INDUSTRIALIZED-5.dta;
keep if twithin(1987-4,2011-1);

xi: nbreg all_init_prod   pchg_rxr_yoy_lag2_pre 
	pchg_rxr_yoy_lag2_post
	chg_unemp_yoy_lag2_pre
	chg_unemp_yoy_lag2_post
	fgdp_gr_lag2_pre
	fgdp_gr_lag2_post
	 quarter_pre quarter_post
	i.cty_partner, nolog irr ;

/* STRUCTURAL BREAK FOR RXR? */
test((pchg_rxr_yoy_lag2_pre)-(pchg_rxr_yoy_lag2_post))=0;

/* STRUCTURAL BREAK FOR UNEMPLOYMENT CHANGE? */
test((chg_unemp_yoy_lag2_pre)-(chg_unemp_yoy_lag2_post))=0;

/* STRUCTURAL BREAK FOR FOREIGN GDP SHOCK? */
test((fgdp_gr_lag2_pre)-(fgdp_gr_lag2_post))=0;

/* STRUCTURAL BREAK FOR TIME TREND? */
test((quarter_pre)-(quarter_post))=0;


/* ************************* */
/* 3. AT TWO LAGS WITH IMPORT GROWTH */
/* ************************* */

#delimit;
clear;
use data\quarterly_bilateral\quarterly_bi_INDUSTRIALIZED-5.dta;
keep if twithin(1987-4,2011-1);

xi: nbreg all_init_prod  pchg_rxr_yoy_lag2_pre 
	pchg_rxr_yoy_lag2_post
	chg_unemp_yoy_lag2_pre
	chg_unemp_yoy_lag2_post
	fgdp_gr_lag2_pre
	fgdp_gr_lag2_post
	 quarter_pre quarter_post
 	imp_gr_yoy_lag2_pre
	imp_gr_yoy_lag2_post
	i.cty_partner, nolog  irr;

/* STRUCTURAL BREAK FOR RXR? */
test((pchg_rxr_yoy_lag2_pre)-(pchg_rxr_yoy_lag2_post))=0;

/* STRUCTURAL BREAK FOR UNEMPLOYMENT CHANGE? */
test((chg_unemp_yoy_lag2_pre)-(chg_unemp_yoy_lag2_post))=0;

/* STRUCTURAL BREAK FOR FOREIGN GDP SHOCK? */
test((fgdp_gr_lag2_pre)-(fgdp_gr_lag2_post))=0;
	
/* STRUCTURAL BREAK FOR TIME TREND? */
test((quarter_pre)-(quarter_post))=0;	

/* STRUCTURAL BREAK? */
test((imp_gr_yoy_lag2_pre)-(imp_gr_yoy_lag2_post))=0;






/* **************** US AS POLICY IMPOSING ECONOMY ********************** */

#delimit;
clear;
use data\quarterly_bilateral\quarterly_bi_INDUSTRIALIZED-5.dta;
keep if twithin(1987-4,2011-1);

keep if cty_code=="USA";

/* 4. AT ONE LAG */

xi: nbreg all_init_prod   pchg_rxr_yoy_lag1_pre 
	pchg_rxr_yoy_lag1_post
	chg_unemp_yoy_lag1_pre
	chg_unemp_yoy_lag1_post
	fgdp_gr_lag1_pre
	fgdp_gr_lag1_post
	 quarter_pre quarter_post
	i.cty_partner, nolog irr ;

/* STRUCTURAL BREAK FOR RXR? */
test((pchg_rxr_yoy_lag1_pre)-(pchg_rxr_yoy_lag1_post))=0;

/* STRUCTURAL BREAK FOR UNEMPLOYMENT CHANGE? */
test((chg_unemp_yoy_lag1_pre)-(chg_unemp_yoy_lag1_post))=0;

/* STRUCTURAL BREAK FOR FOREIGN GDP SHOCK? */
test((fgdp_gr_lag1_pre)-(fgdp_gr_lag1_post))=0;

/* STRUCTURAL BREAK FOR TIME TREND? */
test((quarter_pre)-(quarter_post))=0;

/* ************************* */
/* CREATE SUMMARY STATISTICS FOR TABLE 1 */
/* ************************* */


keep if e(sample)==1;
/*Create a dummy for the pre-crisis to construct summary statistics */
gen pre_crisis=.;
replace pre_crisis=1 if twithin(1987-4,2008-4);

sort pre_crisis;
by pre_crisis: sum all_init_prod ad_init_prod pchg_rxr_yoy chg_unemp_yoy rgdp_gr fgdp_gr imp_gr_yoy;


/* 5. AT TWO LAGS */
	
xi: nbreg all_init_prod   pchg_rxr_yoy_lag2_pre 
	pchg_rxr_yoy_lag2_post
	chg_unemp_yoy_lag2_pre
	chg_unemp_yoy_lag2_post
	fgdp_gr_lag2_pre
	fgdp_gr_lag2_post
	 quarter_pre quarter_post
	i.cty_partner, nolog irr ;

/* STRUCTURAL BREAK FOR RXR? */
test((pchg_rxr_yoy_lag2_pre)-(pchg_rxr_yoy_lag2_post))=0;

/* STRUCTURAL BREAK FOR UNEMPLOYMENT CHANGE? */
test((chg_unemp_yoy_lag2_pre)-(chg_unemp_yoy_lag2_post))=0;

/* STRUCTURAL BREAK FOR FOREIGN GDP SHOCK? */
test((fgdp_gr_lag2_pre)-(fgdp_gr_lag2_post))=0;

/* STRUCTURAL BREAK FOR TIME TREND? */
test((quarter_pre)-(quarter_post))=0;



/* **************** EU AS POLICY IMPOSING ECONOMY ********************** */

#delimit;
clear;
use data\quarterly_bilateral\quarterly_bi_INDUSTRIALIZED-5.dta;
keep if twithin(1987-4,2011-1);

keep if cty_code=="EUN";

/* 6. AT ONE LAG */

xi: nbreg all_init_prod   pchg_rxr_yoy_lag1_pre 
	pchg_rxr_yoy_lag1_post
	chg_unemp_yoy_lag1_pre
	chg_unemp_yoy_lag1_post
	fgdp_gr_lag1_pre
	fgdp_gr_lag1_post
	 quarter_pre quarter_post
	i.cty_partner, nolog irr ;

/* STRUCTURAL BREAK FOR RXR? */
test((pchg_rxr_yoy_lag1_pre)-(pchg_rxr_yoy_lag1_post))=0;

/* STRUCTURAL BREAK FOR UNEMPLOYMENT CHANGE? */
test((chg_unemp_yoy_lag1_pre)-(chg_unemp_yoy_lag1_post))=0;

/* STRUCTURAL BREAK FOR FOREIGN GDP SHOCK? */
test((fgdp_gr_lag1_pre)-(fgdp_gr_lag1_post))=0;

/* STRUCTURAL BREAK FOR TIME TREND? */
test((quarter_pre)-(quarter_post))=0;

/* ************************* */
/* CREATE SUMMARY STATISTICS FOR TABLE 1 */
/* ************************* */


keep if e(sample)==1;
/*Create a dummy for the pre-crisis to construct summary statistics */
gen pre_crisis=.;
replace pre_crisis=1 if twithin(1987-4,2008-4);

sort pre_crisis;
by pre_crisis: sum all_init_prod ad_init_prod pchg_rxr_yoy chg_unemp_yoy rgdp_gr fgdp_gr imp_gr_yoy;


/* 7. AT TWO LAGS */
	
xi: nbreg all_init_prod   pchg_rxr_yoy_lag2_pre 
	pchg_rxr_yoy_lag2_post
	chg_unemp_yoy_lag2_pre
	chg_unemp_yoy_lag2_post
	fgdp_gr_lag2_pre
	fgdp_gr_lag2_post
	 quarter_pre quarter_post
	i.cty_partner, nolog irr ;

/* STRUCTURAL BREAK FOR RXR? */
test((pchg_rxr_yoy_lag2_pre)-(pchg_rxr_yoy_lag2_post))=0;

/* STRUCTURAL BREAK FOR UNEMPLOYMENT CHANGE? */
test((chg_unemp_yoy_lag2_pre)-(chg_unemp_yoy_lag2_post))=0;

/* STRUCTURAL BREAK FOR FOREIGN GDP SHOCK? */
test((fgdp_gr_lag2_pre)-(fgdp_gr_lag2_post))=0;

/* STRUCTURAL BREAK FOR TIME TREND? */
test((quarter_pre)-(quarter_post))=0;




/* **************** AUS, CAN, KOR AS POLICY IMPOSING ECONOMY - FOR SUM STATS TABLE ********************** */

#delimit;
clear;
use data\quarterly_bilateral\quarterly_bi_INDUSTRIALIZED-5.dta;
keep if twithin(1987-4,2011-1);

keep if cty_code=="AUS" | cty_code=="CAN" | cty_code=="KOR";


/* ROBUSTNESS: NOT TO REPORT FOR TABLE 4: ESTIMATE TO CREATE SAMPLE FOR SUMMARY STATISTICS */

xi: nbreg all_init_prod  pchg_rxr_yoy_lag1_pre 
	pchg_rxr_yoy_lag1_post
	chg_unemp_yoy_lag1_pre
	chg_unemp_yoy_lag1_post
	fgdp_gr_lag1_pre
	fgdp_gr_lag1_post
	 quarter_pre quarter_post
	i.cty_partner, nolog irr ;

/* ************************* */
/* CREATE SUMMARY STATISTICS FOR TABLE 1 */
/* ************************* */


keep if e(sample)==1;
/*Create a dummy for the pre-crisis to construct summary statistics */
gen pre_crisis=.;
replace pre_crisis=1 if twithin(1987-4,2008-4);

sort pre_crisis;
by pre_crisis: sum all_init_prod ad_init_prod pchg_rxr_yoy chg_unemp_yoy rgdp_gr fgdp_gr imp_gr_yoy;


log close;
