/*	Author :	Chad P. Bown & Meredith A. Crowley				*/
/*	Date : 	27 October 2011								*/
/*	Revised :	8 August 2012								*/
/*	Desc : 		Variable construction for Bown-Crowley macro determinants		*/
/*	Input :		data\quarterly_bilateral\quarterly_bi_macro_policy_*.dta (AUS, CAN, EUN, KOR, USA) 			*/
/*	Output :	data\quarterly_bilateral\quarterly_bi_*.dta (AUS, CAN, EUN, KOR, USA, INDUSTRIALIZED-5), 
				data\quarterly_bi_macro_policy_ALL.dta	*/ 
/*													*/
/*	Next :											*/

clear
set mem 750m

version 7.0
#delimit ;
set more off;

cd MY_PATH;

clear;
use data\quarterly_bilateral\quarterly_bi_macro_policy_AUS.dta;
append using data\quarterly_bilateral\quarterly_bi_macro_policy_CAN.dta;
append using data\quarterly_bilateral\quarterly_bi_macro_policy_EUN.dta;
append using data\quarterly_bilateral\quarterly_bi_macro_policy_KOR.dta;
append using data\quarterly_bilateral\quarterly_bi_macro_policy_USA.dta;


		gen rxr=bilateral_x_index;
		
	egen cty_partner=group(cty_code partner_code);	
		
	 tsset cty_partner quarter, quarterly;
 

	 gen rgdp_gr= c_rgdp_gr_yoy;	 
	 gen rgdp_gr_lag1=L1.rgdp_gr;
	 gen rgdp_gr_lag2=L2.rgdp_gr;
	 
	 gen fgdp_gr=p_rgdp_gr_yoy;
	 
/*	INDIA'S RGDP SERIES IN HAVER ENDS IN 2010, SO SPLICE ITS 2010:Q2-Q4 DATA FROM AN OECD SERIES */
/*	SPLICED SERIES: B1_GE Gross Domestic Product, expenditure approach; GYSA: Growth rate compared to the 
	same quarter, previous year, seasonally adjusted */
	 
		replace fgdp_gr=9.3 if (partner_code=="IND" & twithin(2010-1,2010-3));
		replace fgdp_gr=9.5 if (partner_code=="IND" & twithin(2010-2,2010-4));
		replace fgdp_gr=10.1 if (partner_code=="IND" & twithin(2010-3,2011-1));
	 
	 
	 
	 gen fgdp_gr_lag1 = L1.fgdp_gr;
	 gen fgdp_gr_lag2 = L2.fgdp_gr;
	 
	 gen rxr_lag4 = L4.rxr;
	 
	 gen pchg_rxr_yoy = ((rxr-rxr_lag4)/rxr_lag4)*100;
	 gen pchg_rxr_yoy_lag1 = L1.pchg_rxr_yoy;
	 gen pchg_rxr_yoy_lag2 = L2.pchg_rxr_yoy;
	 
	 gen imports_lag4= L4.imports;
	 gen imp_gr_yoy=((imports-imports_lag4)/imports_lag4)*100;
	 gen imp_gr_yoy_lag2=L2.imp_gr_yoy;
	 
	 gen ln_unemployment=ln(c_unemp_qr);
	 gen ln_unemployment_lag1 = L1.ln_unemployment;
	 gen c_unemp_qr_lag4 = L4.c_unemp_qr;
	 gen chg_unemp_yoy  = c_unemp_qr - c_unemp_qr_lag4;
	 gen chg_unemp_yoy_lag1=L1.chg_unemp_yoy;
	 gen chg_unemp_yoy_lag2=L2.chg_unemp_yoy;
	 gen chg_unemp_yoy_lag3=L3.chg_unemp_yoy;

	 gen all_stock_prod_lag1=L1.all_stock_prod;
	 gen all_stock_prod_lag2=L2.all_stock_prod;
	 
	 gen shared_gdp_lag1=rgdp_gr_lag1*fgdp_gr_lag1;
	 gen shared_gdp_lag2=rgdp_gr_lag2*fgdp_gr_lag2;
	 gen shared_unemp_lag1=chg_unemp_yoy_lag1*fgdp_gr_lag1;
	 gen shared_unemp_lag2=chg_unemp_yoy_lag2*fgdp_gr_lag2;

	 gen zero_fraction_lag4=L4.zero_fraction;
	 gen chg_zero_fraction= zero_fraction - zero_fraction_lag4;
	 gen chg_zero_fraction_lag1= L1.chg_zero_fraction;	
	 gen chg_zero_fraction_lag2= L2.chg_zero_fraction;				

	 gen ten_fraction_lag4=L4.ten_fraction;
	 gen chg_ten_fraction= ten_fraction - ten_fraction_lag4;
	 gen chg_ten_fraction_lag1= L1.chg_ten_fraction;	

	 
	 
	 xtset cty_partner quarter;

gen partner_CHN=0;
replace partner_CHN=1 if partner_code=="CHN";

/* GENERATE POST-2008 DUMMY FOR DIFFERENTIALS */

generate post=0;
replace post=1 if twithin(2008-3,2011-1);
gen pre=1-post;

gen pchg_rxr_yoy_lag1_post=pchg_rxr_yoy_lag1*post;
gen pchg_rxr_yoy_lag2_post=pchg_rxr_yoy_lag2*post;
gen chg_unemp_yoy_lag1_post=chg_unemp_yoy_lag1*post;
gen chg_unemp_yoy_lag2_post=chg_unemp_yoy_lag2*post;
gen fgdp_gr_lag1_post=fgdp_gr_lag1*post;
gen fgdp_gr_lag2_post=fgdp_gr_lag2*post;
gen imp_gr_yoy_lag2_post=imp_gr_yoy_lag2*post;
gen quarter_post=quarter*post;

gen pchg_rxr_yoy_lag1_pre=pchg_rxr_yoy_lag1*pre;
gen pchg_rxr_yoy_lag2_pre=pchg_rxr_yoy_lag2*pre;
gen chg_unemp_yoy_lag1_pre=chg_unemp_yoy_lag1*pre;
gen chg_unemp_yoy_lag2_pre=chg_unemp_yoy_lag2*pre;
gen fgdp_gr_lag1_pre=fgdp_gr_lag1*pre;
gen fgdp_gr_lag2_pre=fgdp_gr_lag2*pre;
gen imp_gr_yoy_lag2_pre=imp_gr_yoy_lag2*pre;
gen quarter_pre=quarter*pre;

keep if twithin(1987-4,2011-1);



compress;
save data\quarterly_bilateral\quarterly_bi_macro_policy_ALL.dta, replace;


/* TO CREATE ONE "STACKED" DATA SET OF 5 POLICY-IMPOSING ECONOMIES, KEEP THE TOP 15 TRADING PARTNERS FOR EACH */

/* ** I. USA *************************************************** */
#delimit;
clear;
use data\quarterly_bilateral\quarterly_bi_macro_policy_ALL.dta;

keep if partner_code=="CHN" | partner_code=="EUN" | partner_code=="JPN" | partner_code=="KOR" | partner_code=="TWN" | 
	partner_code=="BRA" | partner_code=="ZAF" | partner_code=="CAN" | partner_code=="IND" | partner_code=="AUS" | 
	partner_code=="MEX" | partner_code=="NZL" | partner_code=="TUR" | partner_code=="IDN" | partner_code=="CHE";

keep if twithin(1987-4,2011-1);
keep if cty_code=="USA";
egen partner_num=group(partner_code);
xtset partner_num quarter;

save data\quarterly_bilateral\quarterly_bi_USA.dta, replace;

/* ** II. EUN *************************************************** */

clear;
use data\quarterly_bilateral\quarterly_bi_macro_policy_ALL.dta;

keep if partner_code=="CHN" | partner_code=="TUR" | partner_code=="IND" | partner_code=="KOR" | partner_code=="BRA" 
	| partner_code=="USA" | partner_code=="JPN" | partner_code=="TWN" | partner_code=="NOR" | partner_code=="IDN" 
	| partner_code=="CHE" | partner_code=="ZAF" | partner_code=="AUS" | partner_code=="NZL" | partner_code=="MEX";

keep if twithin(1998-4,2011-1);
keep if cty_code=="EUN";
egen partner_num=group(partner_code);
xtset partner_num quarter;

save data\quarterly_bilateral\quarterly_bi_EUN.dta, replace;


/* ** III. KOR *************************************************** */
#delimit;
clear;
use data\quarterly_bilateral\quarterly_bi_macro_policy_ALL.dta;

keep if partner_code=="USA" | partner_code=="CHN" | partner_code=="JPN" | partner_code=="IDN" | partner_code=="EUN" 
	| partner_code=="IND" | partner_code=="CAN" | partner_code=="NZL" | partner_code=="TWN"  | partner_code=="CHE" 
	/* | partner_code=="AUS" | partner_code=="TUR" */;

keep if twithin(1987-4,2011-1);
keep if cty_code=="KOR";
egen partner_num=group(partner_code);
xtset partner_num quarter;

save data\quarterly_bilateral\quarterly_bi_KOR.dta, replace;


/* ** IV. AUS *************************************************** */

clear;
use data\quarterly_bilateral\quarterly_bi_macro_policy_ALL.dta;

keep if partner_code=="EUN" | partner_code=="CHN" | partner_code=="KOR" | partner_code=="TWN" | partner_code=="USA" | 
	partner_code=="IDN" | partner_code=="JPN" | partner_code=="BRA" | partner_code=="CAN" | partner_code=="IND" | 
	partner_code=="ZAF" | partner_code=="ISR" | partner_code=="MEX" | partner_code=="TUR" | partner_code=="NOR";

keep if twithin(1987-4,2011-1);
keep if cty_code=="AUS";
egen partner_num=group(partner_code);
xtset partner_num quarter;

save data\quarterly_bilateral\quarterly_bi_AUS.dta, replace;


/* ** V. CAN *************************************************** */
#delimit;
clear;
use data\quarterly_bilateral\quarterly_bi_macro_policy_ALL.dta;

keep if partner_code=="USA" | partner_code=="EUN" | partner_code=="CHN" | partner_code=="BRA" | partner_code=="TWN" 
	| partner_code=="NZL" | partner_code=="KOR" | partner_code=="ZAF" | partner_code=="IND" | partner_code=="JPN" 
	| partner_code=="TUR" | partner_code=="AUS" | partner_code=="IDN" | partner_code=="MEX" | partner_code=="CHE";

keep if twithin(1987-4,2011-1);
keep if cty_code=="CAN";
egen partner_num=group(partner_code);
xtset partner_num quarter;



save data\quarterly_bilateral\quarterly_bi_CAN.dta, replace;

append using data\quarterly_bilateral\quarterly_bi_USA.dta;
append using data\quarterly_bilateral\quarterly_bi_EUN.dta;
append using data\quarterly_bilateral\quarterly_bi_KOR.dta;
append using data\quarterly_bilateral\quarterly_bi_AUS.dta;

save data\quarterly_bilateral\quarterly_bi_INDUSTRIALIZED-5.dta, replace;
